'use strict';

var CacheAppServices = angular.module('CacheAppServices', []);

CacheAppServices.factory('CacheApp', ['$cookies',
  function ($cookies) {

    var cacheAppFactory = {};

    cacheAppFactory.setSessao = function (sessao) {
        $cookies.putObject('SessaoUsuarioAcessos', sessao.AcessosObras);
        delete sessao.AcessosObras;
        $cookies.putObject('SessaoUsuario', sessao);
        sessao.AcessosObras = $cookies.getObject('SessaoUsuarioAcessos');
    }
    cacheAppFactory.getSessao = function () {
        var sessao = $cookies.getObject('SessaoUsuario');
        if (sessao) sessao.AcessosObras = $cookies.getObject('SessaoUsuarioAcessos');
        return sessao;
    }
    cacheAppFactory.delSessao = function (callBackFunction) {
        $cookies.remove('SessaoUsuarioAcessos');
        $cookies.remove('SessaoUsuario');
        $cookies.remove('Idioma');
        callBackFunction();
    }

    cacheAppFactory.setIdioma = function (Idioma) {
        $cookies.putObject('Idioma', Idioma);
    }
    cacheAppFactory.getIdioma = function () {
        return $cookies.getObject('Idioma');
    }
    cacheAppFactory.delIdioma = function () {
        $cookies.remove('Idioma');
    }

    cacheAppFactory.setConstrucao = function (construcao) {
        $cookies.putObject('ConstrucaoAcessos', construcao.Acessos);
        delete construcao.Acessos;
        if (construcao.fornecedoresAll) 
            delete construcao.fornecedoresAll;
        $cookies.putObject('Construcao', construcao);
        construcao.Acessos = $cookies.getObject('ConstrucaoAcessos');
    }

    cacheAppFactory.getConstrucao = function () {
        var obra = $cookies.getObject('Construcao');
        var acessos = $cookies.getObject('ConstrucaoAcessos');
        if (obra) obra.Acessos = acessos;
        
        return obra;
    }

    cacheAppFactory.delConstrucao = function () {
        $cookies.remove('ConstrucaoAcessos');
        $cookies.remove('Construcao');
    }

    cacheAppFactory.setSolicitacao = function (solicitacao) {
        $cookies.putObject('Solicitacao', solicitacao);
    }
    cacheAppFactory.getSolicitacao = function () {
        return $cookies.getObject('Solicitacao');
    }
    cacheAppFactory.delSolicitacao = function () {
        $cookies.remove('Solicitacao');
    }

    cacheAppFactory.setMaterial = function (material) {
        $cookies.putObject('Material', material);
    }
    cacheAppFactory.getMaterial = function () {
        return $cookies.getObject('Material');
    }
    cacheAppFactory.delMaterial = function () {
        $cookies.remove('Material');
    }

    cacheAppFactory.setListaMaterialAdicionado = function (materiais) {
        $cookies.putObject('ListaMaterialAdicionado', materiais);
    }
    cacheAppFactory.getListaMaterialAdicionado = function () {
        return $cookies.getObject('ListaMaterialAdicionado');
    }
    cacheAppFactory.delListaMaterialAdicionado = function () {
        $cookies.remove('ListaMaterialAdicionado');
    }

    cacheAppFactory.setListaPedido = function (materiais) {
        $cookies.putObject('ListaMaterialPedido', materiais);
    }
    cacheAppFactory.getListaPedido = function () {
        return $cookies.getObject('ListaMaterialPedido');
    }

    cacheAppFactory.setNotaFiscal = function (construcao) {
        $cookies.putObject('NotaFiscal', construcao);
    }
    cacheAppFactory.getNotaFiscal = function () {
        return $cookies.getObject('NotaFiscal');
    }
    cacheAppFactory.delNotaFiscal = function () {
        $cookies.remove('NotaFiscal');
    }

    cacheAppFactory.setParaCadastro = function () {
        $cookies.putObject('ParaCadastro', 'ParaCadastro');
    }
    cacheAppFactory.getParaCadastro = function () {
        return $cookies.getObject('ParaCadastro');
    }
    cacheAppFactory.delParaCadastro = function () {
        $cookies.remove('ParaCadastro');
    }

    cacheAppFactory.setComposicao = function (composicao) {
        $cookies.putObject('Composicao', composicao);
    }
    cacheAppFactory.getComposicao = function () {
        return $cookies.getObject('Composicao');
    }
    cacheAppFactory.delComposicao = function () {
        $cookies.remove('Composicao');
    }

    cacheAppFactory.setDeOnde = function (deOnde) {
        $cookies.putObject('DeOnde', deOnde);
    }
    cacheAppFactory.getDeOnde = function () {
        return $cookies.getObject('DeOnde');
    }
    cacheAppFactory.delDeOnde = function () {
        $cookies.remove('DeOnde');
    }

    cacheAppFactory.setIOS = function () {
        $cookies.putObject('IOS', true);
    }
    cacheAppFactory.isIOS = function () {
        return $cookies.getObject('IOS');
    }
    cacheAppFactory.delIOS = function () {
        $cookies.remove('IOS');
    }

    cacheAppFactory.setDiarioObra = function (diarioObra) {
        $cookies.putObject('DiarioObra', diarioObra);
    }
    cacheAppFactory.getDiarioObra = function () {
        return $cookies.getObject('DiarioObra');
    }
    cacheAppFactory.delDiarioObra = function () {
        $cookies.remove('DiarioObra');
    }

    cacheAppFactory.setCountBack = function () {
        var count = $cookies.getObject('CountBack');
        count = count ? (count + 2) : 2;
        $cookies.putObject('CountBack', count);
    }
    cacheAppFactory.getCountBack = function () {
        var count = $cookies.getObject('CountBack');
        if (count)
            $cookies.remove('CountBack');

        count = count ? count : 1;
        return count * (-1);
    }

    cacheAppFactory.getData = function (data) {
        return new Date(data);
    }

    cacheAppFactory.msgBoxAcessoPremium = () => {
        swal(
            'Funcionalidade exclusiva para clientes pagantes.',
            'Atualize sua conta agora mesmo!',
            'warning'
        ).then((result) => {
            window.open(`https://www.vighapp.com/app/index.html#/contrato?from=FUNCAO_PREMIUM`,'_blank');
        })
    }


    return cacheAppFactory;
  }]);
